@@ -4,9 +4,9 @@ require 'pathname'
 module Homesick
   # Various utility methods that are used by Homesick
   module Utils
-    QUIETABLE = ['say_status']
+    QUIETABLE = [:say_status]
 
-    PRETENDABLE = ['system']
+    PRETENDABLE = [:system]
 
     QUIETABLE.each do |method_name|
       define_method(method_name) do |*args|
@@ -150,7 +150,7 @@ module Homesick
 
     def collision_accepted?(destination, source)
       fail "Arguments must be instances of Pathname, #{destination.class.name} and #{source.class.name} given" unless destination.instance_of?(Pathname) && source.instance_of?(Pathname)
-      options[:force] || shell.file_collision(destination) { source }
+      options[:force] || shell.file_collision(destination) { File.binread(source) }
     end
 
     def each_file(castle, basedir, subdirs)
